---
title: Colophon
publish_date: October 31st, 2014
tags:
  - meta
  - code
---

Most blogs, including this one, are reverse-chronologically ordered,
causing the first post to appear last in the archive. This convention
makes a [colophon][colophon] the [King's Pawn Game][kingspawn] of web
authorship; there's no better place to showcase certain implementation
details than the first post of a blog.

This site is generated with [Chert][chert_github][^pronounce], an
open-source static site generator built with [Python][python],
[Markdown][markdown][^emd], [ashes][ashes], [pygments][pygments], and
[YAML][yaml]. Chert is named for a very common [fine-grained
sedimentary rock][chert_rock], often referred to as *flint*, that has
been of critical use to firestarters through the ages.

[^pronounce]: English pronunciation rhymes with *dirt*,
   maintainer/Farsi pronunciation: *chair* with a *t* at the end.
[^emd]: Enhanced Markdown, including support for
   [footnotes][footnotes], [definition lists][deflists], and [tables of
   contents][tocs].

[colophon]: https://en.wiktionary.org/wiki/colophon
[kingspawn]: https://en.wikipedia.org/wiki/King's_Pawn_Game
[chert_github]: https://github.com/mahmoud/chert
[chert_rock]: https://en.wikipedia.org/wiki/Chert
[python]: http://python.org
[markdown]: https://en.wikipedia.org/wiki/Markdown
[footnotes]: https://pythonhosted.org/Markdown/extensions/footnotes.html#syntax
[deflists]: https://pythonhosted.org/Markdown/extensions/definition_lists.html#syntax
[tocs]: https://pythonhosted.org/Markdown/extensions/toc.html#syntax
[ashes]: https://github.com/mahmoud/ashes
[yaml]: https://en.wikipedia.org/wiki/YAML
[pygments]: http://pygments.org/
